@@ -15,6 +15,7 @@ lib2to3_fix_names = set([
     'lib2to3.fixes.fix_operator',
     'lib2to3.fixes.fix_paren',
     'lib2to3.fixes.fix_reduce',
+    'lib2to3.fixes.fix_renames',
     'lib2to3.fixes.fix_repr',
     'lib2to3.fixes.fix_set_literal',
     'lib2to3.fixes.fix_standarderror',
@@ -32,6 +33,8 @@ six_fix_names = set([
     'libmodernize.fixes.fix_dict_six',
     'libmodernize.fixes.fix_filter',
     'libmodernize.fixes.fix_imports_six',
+    'libmodernize.fixes.fix_itertools_six',
+    'libmodernize.fixes.fix_itertools_imports_six',
     'libmodernize.fixes.fix_input_six',
     'libmodernize.fixes.fix_int_long_tuple',
     'libmodernize.fixes.fix_map',
@@ -39,11 +42,14 @@ six_fix_names = set([
     'libmodernize.fixes.fix_raise_six',
     'libmodernize.fixes.fix_unicode',
     'libmodernize.fixes.fix_unicode_type',
+    'libmodernize.fixes.fix_urllib_six',
+    'libmodernize.fixes.fix_unichr',
     'libmodernize.fixes.fix_xrange_six',
     'libmodernize.fixes.fix_zip',
 ])
 
 # Fixes that are opt-in only.
 opt_in_fix_names = set([
+    'libmodernize.fixes.fix_classic_division',
     'libmodernize.fixes.fix_open',
 ])
