@@ -10,9 +10,7 @@ import libmodernize
 class FixDictSix(fix_dict.FixDict):
 
     def transform_iter(self, method_name, node, base):
-        """Call six.iteritems() and friends."""
-        if method_name.startswith(u'view'):
-            method_name = u'iter' + method_name[4:]
+        """Call six.(iter|view)items() and friends."""
         libmodernize.touch_import(None, u'six', node)
         new_node = [n.clone() for n in base]
         new_node[0].prefix = u''
@@ -26,3 +24,9 @@ class FixDictSix(fix_dict.FixDict):
             return super(FixDictSix, self).transform(node, results)
         else:
             return self.transform_iter(method_name, node, results['head'])
+
+    def in_special_context(self, node, isiter):
+        # Redefined from parent class to make "for x in d.items()" count as
+        # in special context; 2to3 only counts for loops as special context
+        # for the iter* methods.
+        return super(FixDictSix, self).in_special_context(node, True)
