@@ -1,8 +1,9 @@
-"""Fixer for it.next() -> advance_iterator(it)"""
+"""Fixer for it.next() -> next(it)"""
+from __future__ import absolute_import
 
 # Local imports
 from lib2to3 import fixer_base
-from lib2to3.fixer_util import touch_import, Name, Call
+from lib2to3.fixer_util import Name, Call
 
 bind_warning = "Calls to builtin next() possibly shadowed by global binding"
 
@@ -16,11 +17,7 @@ class FixNext(fixer_base.BaseFix):
     order = "pre" # Pre-order tree traversal
 
     def transform(self, node, results):
-        assert results
-        base = results.get('base')
-        if not base:
-            return
-        touch_import(None, u'six', node)
+        base = results['base']
         base = [n.clone() for n in base]
         base[0].prefix = u""
-        node.replace(Call(Name(u"six.advance_iterator", prefix=node.prefix), base))
+        node.replace(Call(Name(u"next", prefix=node.prefix), base))
