@@ -2,13 +2,14 @@
 
 raise E, V, T -> six.reraise(E, V, T)
 
-Not very well-tested, based on examples
 """
 # Author : Markus Unterwaditzer
+from __future__ import absolute_import
 
 # Local imports
 from lib2to3 import fixer_base
-from lib2to3.fixer_util import Name, Call, Comma, touch_import
+from lib2to3.fixer_util import Name, Call, Comma
+from libmodernize import touch_import
 
 class FixRaiseSix(fixer_base.BaseFix):
 
@@ -25,6 +26,6 @@ class FixRaiseSix(fixer_base.BaseFix):
         exc.prefix = u""
         val.prefix = tb.prefix = u" "
 
-        touch_import(u'six', u'reraise', node)
+        touch_import(None, u'six', node)
         return Call(Name(u"six.reraise"), [exc, Comma(), val, Comma(), tb],
                     prefix=node.prefix)
